Stan Math Library: stan/math/rev/scal/fun/acos.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

acos.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_REV_SCAL_FUN_ACOS_HPP
2 #define STAN_MATH_REV_SCAL_FUN_ACOS_HPP
3
4 #include <stan/math/rev/core.hpp>
5 #include <cmath>
6 #include <valarray>
7
8 namespace stan {
9 namespace math {
10
11 namespace {
12 class acos_vari : public op_v_vari {
13 public:
14 explicit acos_vari(vari* avi) :
15 op_v_vari(std::acos(avi->val_), avi) {
16 }
17 void chain() {
18 avi_->adj_ -= adj_ / std::sqrt(1.0 - (avi_->val_ * avi_->val_));
19 }
20 };
21 }
22
59 inline var acos(const var& a) {
60 return var(new acos_vari(a.vi_));
61 }
62
63 }
64 }
65 #endif
core.hpp
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
std
Definition: std_numeric_limits.hpp:7
stan::math::var
Independent (input) and dependent (output) variables for gradients.
Definition: var.hpp:31
stan::math::var::vi_
vari * vi_
Pointer to the implementation of this variable.
Definition: var.hpp:43
stan::math::acos
fvar< T > acos(const fvar< T > &x)
Definition: acos.hpp:14

[ Stan Home Page ] © 2011–2016, Stan Development Team.